@@ -13,7 +13,7 @@ pub fn world_time(args: TokenStream, input: TokenStream) -> TokenStream {
     if let syn::Fields::Named(ref mut fields) = item_struct.fields {
         fields.named.push(
             syn::Field::parse_named
-                .parse2(quote! { time: std::sync::atomic::AtomicI64 })
+                .parse2(quote! { game_time: crossbeam::atomic::AtomicCell })
                 .unwrap(),
         );
     }
@@ -21,14 +21,15 @@ pub fn world_time(args: TokenStream, input: TokenStream) -> TokenStream {
     let tokens = quote! {
         #item_struct
         use rollo::server::WorldTime;
+        pub use crossbeam::atomic::AtomicCell;
 
         impl WorldTime for #name {
-            fn time(&self) -> i64 {
-                self.time.load(std::sync::atomic::Ordering::Acquire)
+            fn time(&self) -> rollo::game::GameTime {
+                self.time.load()
             }
 
-            fn update_time(&self, new_time: i64) {
-                self.time.store(new_time, std::sync::atomic::Ordering::Release);
+            fn update_time(&self, new_time: rollo::game::GameTime) {
+                self.time.store(new_time);
             }
         }
     };
